@@ -4,7 +4,6 @@
 #' on numerical vectors and numerical components of data frames.
 #' @rdname confint
 #'
-#' @method confint numeric
 #' @param object The data frame or numerical vector.
 #' @param parm not used -- for compatibility with other confint methods
 #' @param level confidence level (default 0.95)
@@ -46,7 +45,6 @@ confint.numeric = function(object, parm, level=0.95, ..., method="stderr",
 }
 # =================
 #' @rdname confint
-#' @method confint do.data.frame
 confint.do.data.frame = function(object, parm, level=0.95, ..., 
                                  method="stderr", margin.of.error="stderr" %in% method) {
   method <- match.arg(method, c("se","stderr","percentile","quantile"), several.ok=TRUE) # which method was selected
@@ -102,18 +100,17 @@ confint.do.data.frame = function(object, parm, level=0.95, ...,
   data.frame( name=res$name, center=(res[[2]]+res[[3]])/2,
               margin.of.error=(res[[3]]-res[[2]])/2)
 }
+
 .mosaic.get.ci = function( vals, level, method ) {
   alpha <- (1-level)/2
   if( method == "stderr" ) res = mean(vals, na.rm=TRUE) + 
-    c(-1,1)*sd(vals, na.rm=TRUE)*
-    qt(1-alpha, sum(!is.na(vals))-1 )
+    c(-1,1) * sd(vals, na.rm=TRUE) * qt(1-alpha, sum(!is.na(vals))-1)
   # the sum(!is.na(vals)) above is to account for NAs in finding the degrees of freedom
-  else res = qdata( c(alpha, 1-alpha), vals )
+  else res = quantile(vals, c(alpha, 1-alpha) )
   return(res)
 }
 
 #' @rdname confint
-#' @method confint data.frame
 #' 
 confint.data.frame = function(object, parm, level=0.95, ... )  {
   results <- list()
@@ -136,4 +133,4 @@ confint.data.frame = function(object, parm, level=0.95, ... )  {
   row.names(results) <- names(object) 
   
   return(results)
-}
\ No newline at end of file
+}
