@@ -72,14 +72,20 @@ do <- function(n=1L, cull=NULL, mode='default', algorithm=1.0, parallel=TRUE) {
 	return(as.data.frame(x))
 	}
 
-#' @rdname mosaic-internal
-#' @keywords internal
-#' @details
-#' \code{.clean_names} removes unwanted characters from character vector
+#' Nice names
+#'
+#' Convert a character vector into a similar character vector that would 
+#' work better as names in a data frame by avoiding certain awkward characters
+#'
+#' @rdname nicenames
 #' @param x a character vector
 #' @return a character vector
+#' @export
+#' @examples
+#' nice_names( c("bad name", "name (crazy)", "a:b", "two-way") )
+
  
-.clean_names <- function(x) {
+nice_names <- function(x) {
 	x <- gsub('\\(Intercept\\)','Intercept', x)
 	x <- gsub('resample\\(','', x)
 	x <- gsub('sample\\(','', x)
@@ -88,6 +94,7 @@ do <- function(n=1L, cull=NULL, mode='default', algorithm=1.0, parallel=TRUE) {
 	x <- gsub('-','.', x)
 	x <- gsub(':','.', x)
 	x <- gsub('\\)','', x)
+	x <- gsub(' ','.', x)
 	return(x)
 }
 
@@ -238,13 +245,13 @@ if(FALSE) {
 	} #
 	if (any(class(object)=='lme')){ # for mixed effects models
 		result <- object
-		names(result) <- .clean_names(names(result))
+		names(result) <- nice_names(names(result))
 		return( object$coef$fixed )
 	}
 	if (inherits(object,c('lm','groupwiseModel')) ) {
 		sobject <- summary(object)
 		result <-  c( coef(object), sigma=sobject$sigma, r.squared = sobject$r.squared ) 
-		names(result) <- .clean_names(names(result))
+		names(result) <- nice_names(names(result))
 		return(result)
 	}
 	if (any(class(object)=='htest') ) {
@@ -379,6 +386,9 @@ setMethod("*",
                     "vector" = unlist(resultsList)  
       ) 
       class(result) <- c(paste('do', class(result)[1], sep="."), class(result))
+	  if (inherits( result, "data.frame")) {
+		  names(result) <- nice_names(names(result))
+	  }
       return(result)
     }
   
@@ -448,6 +458,9 @@ setMethod("*",
 		if (dim(result)[2] == 1 & is.null(nm) ) result <- data.frame(result=result[,1]) 
 
     class(result) <- c(paste("do",class(result)[1], sep="."), class(result))
+	if (inherits( result, "data.frame")) { 
+		names(result) <- nice_names(names(result))
+	}
     return(result)
 	}
 )
