@@ -7,7 +7,10 @@
 #' @param data Data frame containing the variables to be plotted.  If not specified, 
 #' the variables will be looked up in the local environment
 #'
-#' @param add If \code{TRUE}, overlay the scatter plot on the current plot.
+#' @param add If \code{TRUE}, add points as a new layer to an existing plot.
+#' If \code{NULL}, the value of \code{under} will be used.
+#' 
+#' @param under If \code{TRUE}, the new layer will be underneat existing layers.
 #' 
 #' @param panelfun Lattice panel function to be used for adding.  Set only if you want something other
 #' than a scatter plot.  Mainly, this is intended to add new functionality through other functions.
@@ -18,7 +21,10 @@
 #' 
 #' @param \dots additional arguments
 #' 
-#' @return A lattice graphics object (if \code{add=FALSE})
+#' @param plot a trellis plot, by default the most recently created one.  If \code{add} is \code{TRUE},
+#' new points will be added as a new layer to \code{plot}.
+#' 
+#' @return A trellis graphics object 
 #' 
 #' @seealso \code{\link{plotFun}}
 #' @export
@@ -28,12 +34,17 @@
 #' plotFun( f(length=length,sex="G")~length, add=TRUE, col="pink")
 #' plotFun( f(length=length,sex="B")~length, add=TRUE)
 
-plotPoints <- function( x, data=parent.frame(),add=FALSE,
-                        panelfun=panel.xyplot,plotfun=xyplot,...) {
+plotPoints <- function( x, data=parent.frame(), add=NULL, under=FALSE,
+                        panelfun=panel.xyplot, plotfun=xyplot, ..., plot=trellis.last.object()
+                        ) {
+  if (is.null(add)) add <- under
   if (!add) return(plotfun(x, data=data, ...))
-  else {
+  # else we're adding on
     xpts <- evalSubFormula(rhs(x),data=data)
     ypts <- evalSubFormula(lhs(x),data=data)
-    ladd(panelfun(xpts[[1]],ypts[[1]],...))
-  }
+    dots <- list(...)
+    plot + latticeExtra::layer( 
+      do.call( panelfun, c(list(xpts[[1]],ypts[[1]]),dots)),
+               data=as.list(environment()),
+               under=under)
 }
\ No newline at end of file
